@@ -159,8 +159,8 @@ decoded_cb (DBusGProxy  *proxy,
             const gchar *file,
             gpointer     user_data)
 {
-    gchar *argv[] = {"ringtoned-fixwav", NULL, NULL};
     gchar *decoded;
+    gchar *argv[4];;
 
     if (g_strcmp0 (category, decoder_category) != 0 ||
         g_strcmp0 (file, current_file) != 0)
@@ -172,12 +172,25 @@ decoded_cb (DBusGProxy  *proxy,
     DEBUG ("Decoded %s", current_file);
 
     decoded = get_decoded_name_for_file (current_file);
-    argv[1] = decoded;
+    argv[0] = "ringtoned-fixwav";
+    if (ringtoned_debug_is_enabled ())
+    {
+        argv[1] = "-d";
+        argv[2] = decoded;
+        argv[3] = NULL;
+    }
+    else
+    {
+        argv[1] = decoded;
+        argv[2] = NULL;
+    }
+
     g_spawn_async (NULL, argv, NULL, G_SPAWN_SEARCH_PATH, NULL, NULL,
             NULL, NULL);
-    g_free (decoded);
 
     file_processed ();
+
+    g_free (decoded);
 }
 
 static void
