@@ -113,6 +113,7 @@ play_real (RingtonedCall *self)
 {
     ca_proplist *props;
     const gchar *playable;
+    gint r;
 
     g_return_if_fail (self->priv->ca_ctx);
 
@@ -126,8 +127,10 @@ play_real (RingtonedCall *self)
 
     self->priv->playing = TRUE;
 
-    ca_context_play_full (self->priv->ca_ctx, ID_RINGTONE, props,
+    r = ca_context_play_full (self->priv->ca_ctx, ID_RINGTONE, props,
             playback_finished_cb, self);
+    if (r != CA_SUCCESS)
+        DEBUG ("Playing error %d: %s", r, ca_strerror (r));
 
     ca_proplist_destroy (props);
 }
